@@ -966,21 +966,21 @@ int new_editor (int number, int x, int y, int columns, int lines, char *f, char
 	    f = 0;
 	    t = "";
 	} else if (!*d && *f != '/')
-	    d = catstrs (current_dir, "/", 0);
+	    d = catstrs (current_dir, "/", NULL);
     }
-    q = catstrs ("editor", itoa (edit_count), 0);
+    q = catstrs ("editor", itoa (edit_count), NULL);
     CPushFont ("editor", 0);
-    win = CDrawDialog (p = catstrs ("wineditor", itoa (edit_count), 0), main_window, x, y);
+    win = CDrawDialog (p = catstrs ("wineditor", itoa (edit_count), NULL), main_window, x, y);
     CPopFont ();
 
     CGetHintPos (&xe, &ye);
     if (option_toolbar) {
 	for (i = 0; i < NUM_TOOL_BUTTONS; i++) {
 	    CWidget *w;
-	    w = CDrawPixmapButton (catstrs (q, ".B", itoa (i), 0), win,
+	    w = CDrawPixmapButton (catstrs (q, ".B", itoa (i), NULL), win,
 			3, ye + i * 25, 25, 25, toolbar_buttons[i], '0');
 	    if (toolbar_cmd[i] == CK_Util) {
-		CDrawMenuButton (catstrs (q, ".util", 0), w->winid, main_window,
+		CDrawMenuButton (catstrs (q, ".util", NULL), w->winid, main_window,
 		     25 + 10, -65, AUTO_SIZE, 0, _ (" Utility "), 0, 0, 0, 0);
 	    }
 	    w->takes_focus = 0;
@@ -989,8 +989,8 @@ int new_editor (int number, int x, int y, int columns, int lines, char *f, char
 	    CSetToolHint (w->ident, _ (toolbar_hints[i]));
 	}
 /* man page "help" */
-	CAddCallback (catstrs (q, ".B", itoa (NUM_TOOL_BUTTONS - 1), 0), help_callback);
-	CSetToolHint (catstrs (q, ".B", itoa (NUM_TOOL_BUTTONS - 1), 0), _ (toolbar_hints[NUM_TOOL_BUTTONS - 1]));
+	CAddCallback (catstrs (q, ".B", itoa (NUM_TOOL_BUTTONS - 1), NULL), help_callback);
+	CSetToolHint (catstrs (q, ".B", itoa (NUM_TOOL_BUTTONS - 1), NULL), _ (toolbar_hints[NUM_TOOL_BUTTONS - 1]));
 	xe = 25 + 4;
     }
     edit_set_syntax_change_callback (change_syntax_type);
@@ -999,7 +999,7 @@ int new_editor (int number, int x, int y, int columns, int lines, char *f, char
     new_edit = CDrawEditor (q, win, xe, ye, columns * FONT_MEAN_WIDTH,
 			    lines * FONT_PIX_PER_LINE, t, f, d, EDITOR_HORIZ_SCROLL, size);
     if (!new_edit) {
-	CDestroyWidget (catstrs ("wineditor", itoa (edit_count), 0));
+	CDestroyWidget (catstrs ("wineditor", itoa (edit_count), NULL));
 	CPopFont ();
 	return 0;
     }
@@ -1018,9 +1018,9 @@ int new_editor (int number, int x, int y, int columns, int lines, char *f, char
     extents_width = max (x, extents_width);
     extents_height = max (y, extents_height);
 
-    (CIdent (catstrs (q, ".text", 0)))->position |= (POSITION_BOTTOM | POSITION_WIDTH);
-    (CIdent (catstrs (q, ".vsc", 0)))->position |= (POSITION_RIGHT | POSITION_HEIGHT);
-    (CIdent (catstrs (q, ".hsc", 0)))->position |= (POSITION_BOTTOM | POSITION_WIDTH);
+    (CIdent (catstrs (q, ".text", NULL)))->position |= (POSITION_BOTTOM | POSITION_WIDTH);
+    (CIdent (catstrs (q, ".vsc", NULL)))->position |= (POSITION_RIGHT | POSITION_HEIGHT);
+    (CIdent (catstrs (q, ".hsc", NULL)))->position |= (POSITION_BOTTOM | POSITION_WIDTH);
 
     memmove (&(edit[number + 1]), &(edit[number]), (last_edit - number) * sizeof (CWidget *));
     last_edit++;
@@ -1085,7 +1085,7 @@ static int file_is_open (char *p)
 	}
     if (r) {
 	CPushFont ("widget", 0);
-	r = CQueryDialog (0, 0, 0, _ (" Warning "), catstrs (_ (" This file is already open. Open another? "), "\n", p, 0), _ ("Yes"), _ ("No"), 0);
+	r = CQueryDialog (0, 0, 0, _ (" Warning "), catstrs (_ (" This file is already open. Open another? "), "\n", p, NULL), _ ("Yes"), _ ("No"), NULL);
 	CPopFont ();
     }
     free (p);
@@ -1146,7 +1146,7 @@ int new_file_callback (char *full_file_name,...)
 	va_start (ap, full_file_name);
 	t = va_arg (ap, char *);
 	size = va_arg (ap, unsigned long);
-	x = new_editor (0, x, y, columns, lines, NEW_WINDOW_FROM_TEXT, d, t, size);
+	x = new_editor (0, x, y, columns, lines, NEW_WINDOW_FROM_TEXT, d, (char *) t, (unsigned long) size);
 	va_end (ap);
     } else {
 	x = new_editor (0, x, y, columns, lines, full_file_name, d);
@@ -1259,10 +1259,10 @@ void menu_browse_cmd (unsigned long ignored)
 {
     int l;
     for (l = 0;; l++)
-	if (!CIdent (catstrs ("_cfileBr", itoa (l), 0)))
+	if (!CIdent (catstrs ("_cfileBr", itoa (l), NULL)))
 	    break;
-    CDrawBrowser (catstrs ("_cfileBr", itoa (l), 0), CRoot, 0, 0, current_dir, "", _(" File Browser "));
-    (CIdent (catstrs ("_cfileBr", itoa (l), 0)))->position |= WINDOW_UNMOVEABLE;
+    CDrawBrowser (catstrs ("_cfileBr", itoa (l), NULL), CRoot, 0, 0, current_dir, "", _(" File Browser "));
+    (CIdent (catstrs ("_cfileBr", itoa (l), NULL)))->position |= WINDOW_UNMOVEABLE;
 }
 
 void menu_jump_to_file (unsigned long ignored)
@@ -1375,7 +1375,7 @@ void update_wlist (void)
 
     if (last_edit > 0) {
 	for (i = 0; i < last_edit; i++) {
-	    m[i + WLIST_ITEMS].text = (char *) strdup (catstrs (" ", edit[i]->editor->filename, "  ", 0));
+	    m[i + WLIST_ITEMS].text = (char *) strdup (catstrs (" ", edit[i]->editor->filename, "  ", NULL));
 	    m[i + WLIST_ITEMS].hot_key = 0;
 	    m[i + WLIST_ITEMS].call_back = wlist_callback;
 	    if (i == current_edit)
@@ -1415,11 +1415,11 @@ int read_config (void)
     float x, y;
     int n = 0, num_read = 0, i;
     DIR *dir;
-    dir = opendir (catstrs (home_dir, EDIT_DIR, "/.t", 0));
+    dir = opendir (catstrs (home_dir, EDIT_DIR, "/.t", NULL));
     s = get_options_section (editor_options_file, "[Files]");
     if (!dir) {
-	mkdir (catstrs (home_dir, EDIT_DIR, 0), 0700);
-	mkdir (catstrs (home_dir, EDIT_DIR, "/.t", 0), 0700);
+	mkdir (catstrs (home_dir, EDIT_DIR, NULL), 0700);
+	mkdir (catstrs (home_dir, EDIT_DIR, "/.t", NULL), 0700);
     }
     if (dir)
 	closedir (dir);
@@ -1565,7 +1565,7 @@ int open_drop_file (XEvent * xevent, CEvent * cwevent)
 	} else if (data_type != DndRawData && data_type != DndText) {	/* we are going to allow nulls in DndText */
 	    size = strnlen ((char *) data, size);
 	}
-	new_file_callback (NEW_WINDOW_FROM_TEXT, data, size);
+	new_file_callback (NEW_WINDOW_FROM_TEXT, (char *) data, (unsigned long) size);
     }
     if (data)
 	free (data);
@@ -1610,10 +1610,10 @@ static void open_drop_file (unsigned char *data, int size, Atom type)
 	    new_file_callback (f);
 	    free (f);
 	} else {
-	    new_file_callback (NEW_WINDOW_FROM_TEXT, data, size);
+	    new_file_callback (NEW_WINDOW_FROM_TEXT, (char *) data, (unsigned long) size);
 	}
     } else {
-	new_file_callback (NEW_WINDOW_FROM_TEXT, data, size);
+	new_file_callback (NEW_WINDOW_FROM_TEXT, (char *) data, (unsigned long) size);
     }
     return;
 }
@@ -1856,7 +1856,7 @@ static void main_loop (void)
 		int i;
 		i = CQueryDialog (0, 0, 0,
 				  _ (" Quit "), _ (" Quit Cooledit ? "), _ (" Cancel quit "), _ (" Quit and save all "),
-				  _ (" Quit, do not save "), 0);
+				  _ (" Quit, do not save "), NULL);
 		switch (i) {
 		case 0:
 
@@ -1879,7 +1879,7 @@ static void main_loop (void)
 		break;
 #endif
 	    case CK_Util:
-		CMenuSelectionDialog (CIdent (catstrs (edit[current_edit]->ident, ".util", 0)));
+		CMenuSelectionDialog (CIdent (catstrs (edit[current_edit]->ident, ".util", NULL)));
 		break;
 	    case CK_Load:
 	    case CK_New:
@@ -2041,7 +2041,7 @@ int main (int argc, char **argv)
     get_home_dir ();
 
     if (!editor_options_file)
-	editor_options_file = (char *) strdup (catstrs (DEFAULT_INI_FILE, 0));
+	editor_options_file = (char *) strdup (catstrs (DEFAULT_INI_FILE, NULL));
 
 
     if (!option_suppress_load_options) {
