@@ -29,6 +29,7 @@ void menu_man_cmd (unsigned long ignore)		{ edit_man_page_cmd (CGetEditMenu()->e
 void menu_print_dialog (unsigned long ignore)		{ cooledit_print_dialog (CGetEditMenu()->editor); }
 void menu_insert_shell_output (unsigned long ignore)	{ edit_insert_shell_output (CGetEditMenu()->editor); }
 
+void menu_jump_to_file (unsigned long ignored);
 void edit_a_script_cmd (unsigned long ignored);
 void delete_a_script_cmd (unsigned long ignored);
 void new_script_cmd (unsigned long ignored);
@@ -197,6 +198,8 @@ void CDrawCooleditMenuButtons (Window parent, int x, int y)
     CAddMenuItem ("menu.commandmenu",
 		_("paragraph indent mode\tS-F6/F16"), '~', (void (*) (unsigned long data)) CEditMenuCommand, (unsigned long) CK_Paragraph_Indent_Mode);
 
+    CInsertMenuItemAfter ("menu.filemenu", _("New"),
+		_("Jump to file\tC-j"), '~', menu_jump_to_file, (unsigned long) CK_Jump_To_File);
     CAddMenuItem ("menu.filemenu", "", ' ', (void *) 0, 0);
     CAddMenuItem ("menu.filemenu",
 		_("Print..."), '~', menu_print_dialog, 0L);
