@@ -303,9 +303,9 @@ int save_options_section (const char *file, const char *section, const char *tex
     if (p) {
 	*p++ = 0;
 	p = strstr (p, "\n[");
-	result = catstrs (t, section, "\n", text, p, 0);
+	result = catstrs (t, section, "\n", text, p, NULL);
     } else {
-	result = catstrs (section, "\n", text, "\n", t, 0);
+	result = catstrs (section, "\n", text, "\n", t, NULL);
     }
     free (t);
     return savefile (file, result, strlen (result), 0600);
