@@ -47,9 +47,9 @@
 
 #define INPUTS_WITH_OPTIONS_FREE_STRINGS	0x10000000
 
-int CInputsWithOptions (Window parent, int x, int y, char *heading, \
-	    char **inputs[], char *input_labels[], char *input_names[], \
-    char *input_tool_hint[], int *check_values[], char *check_labels[], \
+int CInputsWithOptions (Window parent, int x, int y, const char *heading,
+	    char **inputs[], char *input_labels[], char *input_names[],
+    char *input_tool_hint[], int *check_values[], char *check_labels[],
 			char *check_tool_hints[], int options, int width);
 
 #endif				/* ! FIND_H */
