@@ -434,7 +434,7 @@ void save_options (void)
 {
     if (save_setup (editor_options_file) < 0)
 	CErrorDialog (main_window, 20, 20, _(" Save Options "), "%s", get_sys_error (
-	catstrs (_(" Error trying to save : "), editor_options_file, " ", 0)));
+	catstrs (_(" Error trying to save : "), editor_options_file, " ", NULL)));
 }
 
 static char *short_name (char *a, char *b)
