@@ -133,7 +133,7 @@ static unsigned char *expand_tabs (unsigned char *old)
     for (i = 0, q = r, p = old; *p; p++, i++)
 	if (*p == '\t') {
 	    int n = postscript_option_tab_size - (i % postscript_option_tab_size);
-	    strncpy (q, spaces, n);
+	    strncpy ((char *) q, (char *) spaces, n);
 	    q += n;
 	    i += n - 1;
 	} else
@@ -295,12 +295,12 @@ static void printLongLines (unsigned char *p)
 		lineLength = maxLength;
 	    temp = p + lineLength;
 	    t = (char *) malloc (maxLength + right_space + strlen ((char *) c) + 1);
-	    strncpy (t, p, lineLength);
+	    strncpy ((char *) t, (char *) p, lineLength);
 	    if (!right_space)
 		right_space = maxLength - lineLength;
 	    spaces = get_spaces (spaces, right_space);
 	    strcpy ((char *) t + lineLength, (char *) spaces);
-	    strcat (t, option_continuation_string);
+	    strcat ((char *) t, (char *) option_continuation_string);
 	    p = (unsigned char *) t;
 	} else {
 	    temp = (unsigned char *) "";
@@ -502,13 +502,13 @@ void postscript_print (void)
 
     top_box = (unsigned char *) malloc (1024);
     sprintf ((char *) top_box, (char *) box_format, llx, lly, urx, lly, urx, ury, llx, ury);
-    strcat (top_box, "gsave .95 setgray fill grestore stroke\n");
+    strcat ((char *) top_box, "gsave .95 setgray fill grestore stroke\n");
 
     lly = postscript_option_bottom_margin;
     ury = lly + postscript_option_header_font_size * 1.3;
     bot_box = (unsigned char *) malloc (1024);
     sprintf ((char *) bot_box, (char *) box_format, llx, lly, urx, lly, urx, ury, llx, ury);
-    strcat (bot_box, "gsave .95 setgray fill grestore stroke\n");
+    strcat ((char *) bot_box, "gsave .95 setgray fill grestore stroke\n");
 
 /* Open the output pipe or file. */
     if (postscript_option_file) {
