@@ -104,7 +104,7 @@ int print_dialog_exists (unsigned char *m)
 {
     char s[2048];
     sprintf (s, " %s: \n %s ", _ ("File exists, shall I overwrite?"), m);
-    if (CQueryDialog (0, 0, 0, _ (" Print "), s, (" Yes "), (" No "), 0) == 0)
+    if (CQueryDialog (0, 0, 0, _ (" Print "), s, (" Yes "), (" No "), NULL) == 0)
 	return 1;
     return 0;
 }
