@@ -627,7 +627,7 @@ static int execute_background_shell (struct shell_cmd *s, char *script, char *na
 	running_shell[i].shell_pool = pool_init ();
 	pool_null (running_shell[i].shell_pool);
     }
-    shell_display_output ((char *) pool_start (running_shell[i].shell_pool), catstrs (s->name, _ (" Output "), 0), goto_file_callback, name);
+    shell_display_output ((char *) pool_start (running_shell[i].shell_pool), catstrs (s->name, _ (" Output "), NULL), goto_file_callback, name);
     CAddWatch (running_shell[i].shell_pipe, shell_pool_update, WATCH_READING, (void *) i);
     return 1;
 }
@@ -692,12 +692,12 @@ static int run_shell (WEdit * e, struct shell_cmd *s, char *cmdline_options, cha
 	edit_save_block (e, hme (BLOCK_FILE), start_mark, end_mark);
     }
     if (s->options & SHELL_OPTION_SAVE_EDITOR_FILE)
-	if (!edit_save_file (e, catstrs (e->dir, e->filename, 0)))
+	if (!edit_save_file (e, catstrs (e->dir, e->filename, NULL)))
 	    if (!edit_save_as_cmd (e))
 		return -1;
 
     script = substitute_strings (s->script,
-	  cmdline_options, catstrs (e->dir, e->filename, 0), "", "", "");
+	  cmdline_options, catstrs (e->dir, e->filename, NULL), "", "", "");
 
     if ((s->options & (SHELL_OPTION_DISPLAY_STDOUT_CONTINUOUS |
 		       SHELL_OPTION_DISPLAY_STDERR_CONTINUOUS |
@@ -731,7 +731,7 @@ static int run_shell (WEdit * e, struct shell_cmd *s, char *cmdline_options, cha
 		if (s->options & SHELL_OPTION_DISPLAY_ERROR_FILE) {
 		    error = loadfile (hme (ERROR_FILE), 0);
 		    if (error) {
-			CTextboxMessageDialog (main_window, 20, 20, 80, 20, catstrs (s->name, _ (" Error "), 0), error, 0);
+			CTextboxMessageDialog (main_window, 20, 20, 80, 20, catstrs (s->name, _ (" Error "), NULL), error, 0);
 			free (error);
 		    }
 		}
@@ -1102,17 +1102,17 @@ int edit_scripts_dialog (Window parent, int x, int y, struct shell_cmd *s)
     ys = y;
     o = (32 - (FONT_PIX_PER_LINE + 2 + TEXT_RELIEF * 2)) / 2;
     for (i = 0; i < NUM_OPTS / 2; i++) {
-	options[i].w = CDrawSwitch (catstrs ("shellopt.", itoa (i), 0), win, x, y, (s->options & options[i].flag) ? 1 : 0, _ (options[i].name), 0);
+	options[i].w = CDrawSwitch (catstrs ("shellopt.", itoa (i), NULL), win, x, y, (s->options & options[i].flag) ? 1 : 0, _ (options[i].name), 0);
 	CSetToolHint (options[i].w->ident, _ (options[i].toolhint));
-	CSetToolHint (catstrs (options[i].w->ident, ".label", 0), _ (options[i].toolhint));
+	CSetToolHint (catstrs (options[i].w->ident, ".label", NULL), _ (options[i].toolhint));
 	CGetHintPos (0, &y);
     }
     x = xs + CImageStringWidth (_ (options[3].name)) + 32 + WIDGET_SPACING * 2 + 10;
     y = ys;
     for (i = NUM_OPTS / 2; i < NUM_OPTS; i++) {
-	options[i].w = CDrawSwitch (catstrs ("shellopt.", itoa (i), 0), win, x, y, (s->options & options[i].flag) ? 1 : 0, _ (options[i].name), 0);
+	options[i].w = CDrawSwitch (catstrs ("shellopt.", itoa (i), NULL), win, x, y, (s->options & options[i].flag) ? 1 : 0, _ (options[i].name), 0);
 	CSetToolHint (options[i].w->ident, _ (options[i].toolhint));
-	CSetToolHint (catstrs (options[i].w->ident, ".label", 0), _ (options[i].toolhint));
+	CSetToolHint (catstrs (options[i].w->ident, ".label", NULL), _ (options[i].toolhint));
 	CGetHintPos (0, &y);
     }
     CPushFont ("editor", 0);
