@@ -68,7 +68,7 @@ void load_trivial_options (void)
 {
     char *f, *s, *e, *p;
     int i;
-    f = loadfile (catstrs (getenv ("HOME"), OPTIONS_FILE, 0), 0);
+    f = loadfile (catstrs (getenv ("HOME"), OPTIONS_FILE, NULL), 0);
     if (!f)
 	return;
     s = strstr (f, "[Options]\n");
