@@ -24,7 +24,7 @@
  * Copyright (C) 1997,1998 Oezguer Kesim <kesim@math.fu-berlin.de>
  * Copyright (C) 1998      Geoff Wing <gcw@pobox.com>
  * Copyright (C) 1998      Alfredo K. Kojima <kojima@windowmaker.org>
- * Copyright (C) 1996-2000 Paul Sheer <psheer@obsidian.co.za>
+ * Copyright (C) 1996-2000 Paul Sheer <psheer@icon.co.za>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1144,7 +1144,8 @@ EXTERN int      display_is_local;
 #endif
 EXTERN short    want_refresh;
 
-EXTERN const char *rs[TOTAL_RS];
+EXTERN char *rs[TOTAL_RS];
+EXTERN char *rs_free[TOTAL_RS];
 
 #ifndef NO_BACKSPACE_KEY
 EXTERN const char *key_backspace;
