@@ -27,6 +27,8 @@
 #include "xdnd.h"
 #include "mad.h"
 
+#undef max
+#undef min
 #define max(x,y)     (((x) > (y)) ? (x) : (y))
 #define min(x,y)     (((x) < (y)) ? (x) : (y))
 
