@@ -289,6 +289,8 @@ int CCheckWindowEvent (Window w, long event_mask, XEvent ** event_return)
     static long mask[CLASTEvent] =
     {99};
 
+    memset (&e, 0, sizeof (e));
+
     if (!event_mask)
 	event_mask = 0xFFFF;
     if (mask[0] == 99) {
@@ -339,6 +341,7 @@ int CKeyPending (void)
 int CSendExpose (Window win, int x, int y, int w, int h)
 {
     XEvent e;
+    memset (&e, 0, sizeof (e));
     e.xexpose.type = Expose;
     e.xexpose.serial = 0;
     e.xexpose.send_event = 1;
@@ -455,6 +458,7 @@ static int pop_region (XExposeEvent * e, Window w)
 static void pop_all_regions (Window w)
 {
     XEvent e;
+    memset (&e, 0, sizeof (e));
     while (!pop_region (&(e.xexpose), w)) {
 	e.type = InternalExpose;
 	CSendEvent (&e);
@@ -1164,13 +1168,14 @@ void CNextEvent (XEvent * xevent, CEvent * cwevent)
     static Window last_events_window2 = -2;
     static int last_widget1 = 0;
     static int last_widget2 = 0;
-    static XEvent button_repeat =
-    {0};
+    static XEvent button_repeat;
     static int button_repeat_count = 0;
     static Window toolhint_window = 0;
     static int toolhint_count = 0, x_toolhint, y_toolhint;
     int next_event = 0;
 
+    memset (&button_repeat, 0, sizeof (button_repeat));
+
     if (!xevent)
 	xevent = &private_xevent;
     if (!cwevent)
@@ -1391,6 +1396,7 @@ void CNextEvent (XEvent * xevent, CEvent * cwevent)
 	    if (xevent->xclient.data.l[0] == ATOM_WM_DELETE_WINDOW) {
 		if (xevent->xclient.window == CFirstWindow) {
 		    XEvent exit_event;
+		    memset (&exit_event, 0, sizeof (exit_event));
 		    exit_event.type = QuitApplication;
 		    CSendEvent (&exit_event);
 		} else {
