@@ -33,7 +33,7 @@ void CError (const char *fmt,...)
     va_list s;
     char *str;
     va_start (s, fmt);
-    str = vsprintf_alloc (catstrs (" ", fmt, " ", 0), s);
+    str = vsprintf_alloc (catstrs (" ", fmt, " ", NULL), s);
     CFatalErrorDialog (20, 20, str);
     va_end (s);
     free (str);
@@ -606,7 +606,7 @@ Window CDrawHeadedDialog (const char *identifier, Window parent, int x, int y, c
 	int w, h;
 	CTextSize (&w, &h, label);
 	win = CDrawDialog (identifier, parent, x, y);
-	(CDrawText (catstrs (identifier, ".header", 0), win, WIDGET_SPACING, WIDGET_SPACING + 2, label))->position |= POSITION_CENTRE;
+	(CDrawText (catstrs (identifier, ".header", NULL), win, WIDGET_SPACING, WIDGET_SPACING + 2, label))->position |= POSITION_CENTRE;
 	CGetHintPos (&x, &y);
 #ifndef NEXT_LOOK
 	(CDrawBar (win, WIDGET_SPACING, y, 10))->position |= POSITION_FILL;
