@@ -88,6 +88,7 @@
 #include "font.h"
  
 #define ALRM_PER_SECOND 50
+#define NICE_FILENAME_CHARS "+-.0123456789:=@ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz~"
 
 typedef struct initialisation {
     char *name, *display, *geometry, *font, *widget_font, *bg;
@@ -561,7 +562,8 @@ void CShutdown (void);
 void CError (const char *fmt,...);
 
 /* fd watch for internal select */
-int CAddWatch (int fd, void (*callback) (int, fd_set *, fd_set *, fd_set *, void *), int how, void *data);
+#define CAddWatch(fd, cb, how, data) _CAddWatch(__FILE__, __LINE__, fd, cb, how, data)
+int _CAddWatch (char *file, int line, int fd, void (*callback) (int, fd_set *, fd_set *, fd_set *, void *), int how, void *data);
 void CRemoveWatch (int fd, void (*callback) (int, fd_set *, fd_set *, fd_set *, void *), int how);
 #define WATCH_READING	(1<<0)
 #define WATCH_WRITING	(1<<1)
@@ -596,7 +598,7 @@ CWidget *CDrawButton (const char *identifier, Window parent, int x, int y,
 		      int width, int height, const char *label);
 
 /* Set tool hint for a widget */
-void CSetToolHint (const char *ident, char *text);
+void CSetToolHint (const char *ident, const char *text);
 
 /* Draw a button with a bitmap on it, (see dialog.c for example) */
 CWidget *CDrawBitmapButton (const char *identifier, Window parent, int x, int y,
@@ -611,7 +613,7 @@ CWidget *CDrawPixmapButton (const char *identifier, Window parent,
     int x, int y, int width, int height, const char *data[], char start_char);
 
 /* Draws a toggle switch, pass on as the default setting */
-CWidget *CDrawSwitch (const char *identifier, Window parent, int x, int y, int on, char *label, int group);
+CWidget *CDrawSwitch (const char *identifier, Window parent, int x, int y, int on, const char *label, int group);
 
 /* Draw status line  - like a single line text widget but interprets colours */
 CWidget *CDrawStatus (const char *identifier, Window parent, int x, int y, int w, char *str);
@@ -638,6 +640,8 @@ struct file_entry {
 
 char *get_file_list (const char *directory, unsigned long f, char *filter);
 struct file_entry *get_file_entry_list (const char *directory, unsigned long options, char *filter);
+char *user_file_list_search (Window parent, int x, int y, const char *base_name);
+char *user_file_list_complete (Window parent, int x, int y, int lines, int columns, const char *base_name);
 
 CWidget *CDrawFilelist (const char *identifier, Window parent, int x, int y,
 			int width, int height, int line, int column,
@@ -725,6 +729,7 @@ void CRemoveMenuItem (const char *ident, const char *text);
 void CReplaceMenuItem (const char *ident, const char *old_text, const char *new_text, int hot_key, callfn call_back, unsigned long data);
 void CRemoveMenuItemNumber (const char *ident, int i);
 void CInsertMenuItem (const char *ident, const char *after, const char *text, int hot_key, callfn call_back, unsigned long data);
+void CInsertMenuItemAfter (const char *ident, const char *after, const char *text, int hot_key, callfn call_back, unsigned long data);
 int CHasMenuItem (const char *ident, const char *text); /* returns -1 or menu item number */
 
 /* Draws a bitmap inside a sunken window */
@@ -1114,7 +1119,7 @@ struct look {
 				  int preserve);
     struct file_entry *(*get_file_list_line) (CWidget * w, int line);
     void (*search_replace_dialog) (Window parent, int x, int y, char **search_text,
-				   char **replace_text, char **arg_order, char *heading,
+				   char **replace_text, char **arg_order, const char *heading,
 				   int option);
     void (*edit_render_tidbits) (CWidget * wdt);
     CWidget *(*draw_exclam_cancel_button) (char *ident, Window win, int x, int y);
