@@ -61,7 +61,7 @@ char *get_sys_error (const char *s)
 /* The returned value, 'errno' has an unknown meaning */
 	    error_msg = _ ("strange errno");
 #endif
-	return catstrs (s, "\n [", error_msg, "] ", 0);
+	return catstrs (s, "\n [", error_msg, "] ", NULL);
     }
     return (char *) s;
 }
@@ -601,7 +601,7 @@ int CQueryDialog (Window in, int x, int y, const char *heading, const char *firs
 
     CSetSizeHintPos ("_querydialog");
     CMapDialog ("_querydialog");
-    CFocus (CIdent (catstrs ("_query.", b[0], 0)));
+    CFocus (CIdent (catstrs ("_query.", b[0], NULL)));
     CIdent ("_querydialog")->position = WINDOW_ALWAYS_RAISED;
     for (; r < 0;) {
 	CNextEvent (NULL, &cwevent);
