@@ -353,7 +353,7 @@ static char *_user_file_list_search (Window parent, int x, int y, int lines, int
 	strcat (p, FILELIST_FILE);
 	if (stat (p, &st)) {
 	    CErrorDialog (0, 0, 0, _(" Open Personal File List "),
-			  get_sys_error (catstrs (_(" Error trying stat "), p, 0)));
+			  get_sys_error (catstrs (_(" Error trying stat "), p, NULL)));
 	    free (p);
 	    if (whole_file) {
 		free (whole_file);
