@@ -162,7 +162,7 @@ int init_dynamic_edit_buffers (WEdit * edit, const char *filename, const char *t
     if (filename)
 	if ((file = open ((char *) filename, O_RDONLY)) == -1) {
 /* The file-name is printed after the ':' */
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", NULL)));
 	    return 1;
 	}
     edit->curs2 = edit->last_byte;
@@ -351,7 +351,7 @@ int edit_insert_file (WEdit * edit, const char *filename)
 	    free (p);
 	    p = read_pipe (g, 0);
 	    if (strlen (p)) {
-		edit_error_dialog (_ (" Error "), catstrs (_ (" Error reading from pipe: "), p, " ", 0));
+		edit_error_dialog (_ (" Error "), catstrs (_ (" Error reading from pipe: "), p, " ", NULL));
 		free (p);
 		close (f);
 		close (g);
@@ -360,7 +360,7 @@ int edit_insert_file (WEdit * edit, const char *filename)
 	    close (f);
 	    close (g);
 	} else {
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open pipe for reading: "), p, " ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open pipe for reading: "), p, " ", NULL)));
 	    free (p);
 	    return 0;
 	}
@@ -374,11 +374,11 @@ int edit_insert_file (WEdit * edit, const char *filename)
 	    edit_insert_stream (edit, f);
 	    edit_cursor_move (edit, current - edit->curs1);
 	    if (fclose (f)) {
-		edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Error reading file: "), filename, " ", 0)));
+		edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Error reading file: "), filename, " ", NULL)));
 		return 0;
 	    }
 	} else {
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", NULL)));
 	    return 0;
 	}
 #else
@@ -410,34 +410,34 @@ static int check_file_access (WEdit *edit, const char *filename, struct stat *st
     if ((file = open ((char *) filename, O_RDONLY)) < 0) {
 	close (creat ((char *) filename, 0666));
 	if ((file = open ((char *) filename, O_RDONLY)) < 0) {
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (" Fail trying to open the file, ", filename, ", for reading ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (" Fail trying to open the file, ", filename, ", for reading ", NULL)));
 	    return 2;
 	}
     }
 #else
     if ((file = open ((char *) filename, O_RDONLY)) < 0) {
-	edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", 0)));
+	edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open file for reading: "), filename, " ", NULL)));
 	return 1;
     }
 #endif
     if (stat ((char *) filename, st) < 0) {
 	close (file);
 /* The file-name is printed after the ':' */
-	edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Cannot get size/permissions info on file: "), filename, " ", 0)));
+	edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Cannot get size/permissions info on file: "), filename, " ", NULL)));
 	return 1;
     }
     if (S_ISDIR (st->st_mode) || S_ISSOCK (st->st_mode)
 	|| S_ISFIFO (st->st_mode)) {
 	close (file);
 /* The file-name is printed after the ':' */
-	edit_error_dialog (_ (" Error "), catstrs (_ (" Not an ordinary file: "), filename, " ", 0));
+	edit_error_dialog (_ (" Error "), catstrs (_ (" Not an ordinary file: "), filename, " ", NULL));
 	return 1;
     }
     if (st->st_size >= SIZE_LIMIT) {
 	close (file);
 /* The file-name is printed after the ':' */
 	edit_error_dialog (_ (" Error "), catstrs (_ (" File is too large: "), \
-						   filename, _ (" \n Increase edit.h:MAXBUF and recompile the editor. "), 0));
+						   filename, _ (" \n Increase edit.h:MAXBUF and recompile the editor. "), NULL));
 	return 1;
     }
     close (file);
@@ -520,7 +520,7 @@ WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, co
 	dir = "";
     f = (char *) filename;
     if (filename) {
-	f = catstrs (dir, filename, 0);
+	f = catstrs (dir, filename, NULL);
 	if (edit_file_is_open)
 	    if ((*edit_file_is_open) (f)) {
 		if (to_free)
@@ -548,7 +548,7 @@ WEdit *edit_init (WEdit * edit, int lines, int columns, const char *filename, co
     }
     edit->force |= REDRAW_PAGE;
     if (filename) {
-	filename = catstrs (dir, filename, 0);
+	filename = catstrs (dir, filename, NULL);
 	edit_split_filename (edit, (char *) filename);
     } else {
 	edit->filename = (char *) strdup ("");
@@ -724,7 +724,7 @@ void edit_push_action (WEdit * edit, long c,...)
 	edit->undo_stack[sp] = c == CURS_LEFT_LOTS ? CURS_LEFT : CURS_RIGHT;
 	edit->stack_pointer = (edit->stack_pointer + 1) & edit->stack_size_mask;
 	va_start (ap, c);
-	c = -(va_arg (ap, int));
+	c = -(va_arg (ap, long));
 	va_end (ap);
     } else
 #endif				/* ! FAST_MOVE_CURSOR */
@@ -1090,7 +1090,7 @@ int edit_move_backward_lots (WEdit * edit, long increment)
 	increment = edit->curs1;
     if (increment <= 0)
 	return -1;
-    edit_push_action (edit, CURS_RIGHT_LOTS, increment);
+    edit_push_action (edit, CURS_RIGHT_LOTS, (long) increment);
 
     t = r = EDIT_BUF_SIZE - (edit->curs2 & M_EDIT_BUF_SIZE);
     if (r > increment)
