@@ -817,9 +817,9 @@ enum {
 #        define edit_get_save_file(d,f,h) CGetSaveFile(WIN_MESSAGES,d,f,h)
 #        define edit_error_dialog(h,t) CErrorDialog(WIN_MESSAGES,h,"%s",t)
 #        define edit_message_dialog(h,t) CMessageDialog(WIN_MESSAGES,0,h,"%s",t)
-#        define edit_query_dialog2(h,t,a,b) CQueryDialog(WIN_MESSAGES,h,t,a,b,0)
-#        define edit_query_dialog3(h,t,a,b,c) CQueryDialog(WIN_MESSAGES,h,t,a,b,c,0)
-#        define edit_query_dialog4(h,t,a,b,c,d) CQueryDialog(WIN_MESSAGES,h,t,a,b,c,d,0)
+#        define edit_query_dialog2(h,t,a,b) CQueryDialog(WIN_MESSAGES,h,t,a,b,NULL)
+#        define edit_query_dialog3(h,t,a,b,c) CQueryDialog(WIN_MESSAGES,h,t,a,b,c,NULL)
+#        define edit_query_dialog4(h,t,a,b,c,d) CQueryDialog(WIN_MESSAGES,h,t,a,b,c,d,NULL)
 #    endif
 
 #endif				/* ! MIDNIGHT */
