@@ -353,7 +353,7 @@ if (option_latin2) {
     }
     if (!(x_state & MyAltMask)) {
 	if ((x_key == XK_a || x_key == XK_A) && (x_state & ControlMask)) {
-	    command = CKeySymMod (CRawkeyQuery (0, 0, 0, " Execute Macro ", " Press macro hotkey: "));
+	    command = CKeySymMod (CRawkeyQuery (0, 0, 0, _(" Execute Macro "), "%s", _(" Press macro hotkey: ")));
 	    if (!command)
 		command = -1;
 	    else
@@ -546,6 +546,10 @@ if (option_latin2) {
 	    case XK_End:
 		command = CK_End_Page;
 		goto fin;
+	    case XK_J:
+	    case XK_j:
+		command = CK_Jump_To_File;
+		goto fin;
 	    case XK_N:
 	    case XK_n:
 		command = CK_New;
