@@ -282,13 +282,13 @@ int edit_save_file (WEdit * edit, const char *filename)
 	    pclose (file);
 #else
 	    if (pclose (file) > 0) {
-		edit_error_dialog (_ (" Error "), catstrs (_ (" Error writing to pipe: "), p, " ", 0));
+		edit_error_dialog (_ (" Error "), catstrs (_ (" Error writing to pipe: "), p, " ", NULL));
 		free (p);
 		goto error_save;
 	    }
 #endif
 	} else {
-	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open pipe for writing: "), p, " ", 0)));
+	    edit_error_dialog (_ (" Error "), get_sys_error (catstrs (_ (" Failed trying to open pipe for writing: "), p, " ", NULL)));
 	    free (p);
 	    goto error_save;
 	}
@@ -335,7 +335,7 @@ int edit_save_file (WEdit * edit, const char *filename)
     if (filelen != edit->last_byte)
 	goto error_save;
     if (this_save_mode == 2)
-	if (rename (filename, catstrs (filename, option_backup_ext, 0)) == -1)
+	if (rename (filename, catstrs (filename, option_backup_ext, NULL)) == -1)
 	    goto error_save;
     if (this_save_mode > 0)
 	if (rename (savename, filename) == -1)
@@ -518,7 +518,7 @@ int edit_save_as_cmd (WEdit * edit)
 	    edit->force |= REDRAW_COMPLETELY;
 	    return 0;
 	} else {
-	    if (strcmp(catstrs (edit->dir, edit->filename, 0), exp)) {
+	    if (strcmp(catstrs (edit->dir, edit->filename, NULL), exp)) {
 		int file;
 		different_filename = 1;
 		if ((file = open_create ((char *) exp, O_RDONLY, DEFAULT_CREATE_MODE)) != -1) {	/* the file exists */
@@ -625,7 +625,7 @@ static FILE *edit_open_macro_file (const char *r)
 {
     char *filename;
     int file;
-    filename = catstrs (home_dir, MACRO_FILE, 0);
+    filename = catstrs (home_dir, MACRO_FILE, NULL);
     if ((file = open_create (filename, O_CREAT | O_RDWR, DEFAULT_CREATE_MODE)) == -1)
 	return 0;
     close (file);
@@ -660,7 +660,7 @@ int edit_delete_macro (WEdit * edit, int k)
     if (saved_macros_loaded)
 	if ((j = macro_exists (k)) < 0)
 	    return 0;
-    g = fopen (catstrs (home_dir, TEMP_FILE, 0), "w");
+    g = fopen (catstrs (home_dir, TEMP_FILE, NULL), "w");
     if (!g) {
 /* This heads the delete macro error dialog box */
 	edit_error_dialog (_(" Delete macro "),
@@ -694,7 +694,7 @@ int edit_delete_macro (WEdit * edit, int k)
     };
     fclose (f);
     fclose (g);
-    if (rename (catstrs (home_dir, TEMP_FILE, 0), catstrs (home_dir, MACRO_FILE, 0)) == -1) {
+    if (rename (catstrs (home_dir, TEMP_FILE, NULL), catstrs (home_dir, MACRO_FILE, NULL)) == -1) {
 /* This heads the delete macro error dialog box */
 	edit_error_dialog (_(" Delete macro "),
 	   get_sys_error (_(" Error trying to overwrite macro file ")));
@@ -815,9 +815,9 @@ int edit_save_confirm_cmd (WEdit * edit)
 
     if (edit_confirm_save) {
 #ifdef MIDNIGHT
-	f = catstrs (_(" Confirm save file? : "), edit->filename, " ", 0);
+	f = catstrs (_(" Confirm save file? : "), edit->filename, " ", NULL);
 #else
-	f = catstrs (_(" Confirm save file? : "), edit->dir, edit->filename, " ", 0);
+	f = catstrs (_(" Confirm save file? : "), edit->dir, edit->filename, " ", NULL);
 #endif
 /* Buttons to 'Confirm save file' query */
 	if (edit_query_dialog2 (_(" Save file "), f, _("Save"), _("Cancel")))
@@ -830,7 +830,7 @@ int edit_save_confirm_cmd (WEdit * edit)
 /* returns 1 on success */
 int edit_save_cmd (WEdit * edit)
 {
-    if (!edit_save_file (edit, catstrs (edit->dir, edit->filename, 0)))
+    if (!edit_save_file (edit, catstrs (edit->dir, edit->filename, NULL)))
 	return edit_save_as_cmd (edit);
     edit->force |= REDRAW_COMPLETELY;
     edit->modified = 0;
@@ -1192,7 +1192,7 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 	 0, 0, 0, XV_WLAY_DONTCARE, 0},
 	{0}};
 
-    quick_widgets[4].text = catstrs (_ (" Replace with: "), replace_text, 0);
+    quick_widgets[4].text = catstrs (_ (" Replace with: "), replace_text, NULL);
 
     {
 	QuickDialog Quick_input =
@@ -1560,7 +1560,7 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
 	B_CANCEL, B_ENTER, B_SKIP_REPLACE, B_REPLACE_ALL, B_REPLACE_ONE, B_CANCEL
     };
     q = CQueryDialog (WIN_MESSAGES + (edit->curs_line < 8 ? edit->num_widget_lines / 2 * FONT_PIX_PER_LINE + CYof (edit->widget) : 0),
-		      _ (" Replace "), catstrs (_ (" Replace with: "), replace_text, 0), _ ("Replace"), _ ("Skip"), _ ("Replace all"), _ ("Replace one"), _ ("Cancel"), 0);
+		      _ (" Replace "), catstrs (_ (" Replace with: "), replace_text, NULL), _ ("Replace"), _ ("Skip"), _ ("Replace all"), _ ("Replace one"), _ ("Cancel"), NULL);
     edit->force |= REDRAW_COMPLETELY;
     return x[q + 1];
 }
@@ -2263,7 +2263,7 @@ void edit_quit_cmd (WEdit * edit)
 		return;
 	} else if (!strcmp (r, GNOME_STOCK_BUTTON_NO)) {
 	    if (edit->delete_file)
-		unlink (catstrs (edit->dir, edit->filename, 0));
+		unlink (catstrs (edit->dir, edit->filename, NULL));
 	} else {
 	    return;
 	}
@@ -2284,7 +2284,7 @@ void edit_quit_cmd (WEdit * edit)
 	case 2:
 #ifdef MIDNIGHT
 	    if (edit->delete_file)
-		unlink (catstrs (edit->dir, edit->filename, 0));
+		unlink (catstrs (edit->dir, edit->filename, NULL));
 #endif
 	    break;
 	case 0:
@@ -2295,7 +2295,7 @@ void edit_quit_cmd (WEdit * edit)
     }
 #if defined(MIDNIGHT) || defined(GTK)
     else if (edit->delete_file)
-	unlink (catstrs (edit->dir, edit->filename, 0));
+	unlink (catstrs (edit->dir, edit->filename, NULL));
 #endif
 #ifdef MIDNIGHT
     dlg_stop (edit->widget.parent);
@@ -2384,7 +2384,7 @@ int edit_save_block (WEdit * edit, const char *filename, long start, long finish
 /* copies a block to clipboard file */
 static int edit_save_block_to_clip_file (WEdit * edit, long start, long finish)
 {
-    return edit_save_block (edit, catstrs (home_dir, CLIP_FILE, 0), start, finish);
+    return edit_save_block (edit, catstrs (home_dir, CLIP_FILE, NULL), start, finish);
 }
 
 #ifndef MIDNIGHT
@@ -2606,7 +2606,7 @@ int edit_cut_to_X_buf_cmd (WEdit * edit)
 
 void edit_paste_from_X_buf_cmd (WEdit * edit)
 {
-    edit_insert_file (edit, catstrs (home_dir, CLIP_FILE, 0));
+    edit_insert_file (edit, catstrs (home_dir, CLIP_FILE, NULL));
 }
 
 #endif				/* MIDMIGHT */
@@ -2651,7 +2651,7 @@ int edit_save_block_cmd (WEdit * edit)
     char *exp;
     if (eval_marks (edit, &start_mark, &end_mark))
 	return 1;
-    exp = edit_get_save_file (edit->dir, catstrs (home_dir, CLIP_FILE, 0), _ (" Save Block "));
+    exp = edit_get_save_file (edit->dir, catstrs (home_dir, CLIP_FILE, NULL), _ (" Save Block "));
     edit_push_action (edit, KEY_PRESS + edit->start_display);
     if (exp) {
 	if (!*exp) {
@@ -2678,7 +2678,7 @@ int edit_save_block_cmd (WEdit * edit)
 /* returns 1 on success */
 int edit_insert_file_cmd (WEdit * edit)
 {
-    char *exp = edit_get_load_file (edit->dir, catstrs (home_dir, CLIP_FILE, 0), _ (" Insert File "));
+    char *exp = edit_get_load_file (edit->dir, catstrs (home_dir, CLIP_FILE, NULL), _ (" Insert File "));
     edit_push_action (edit, KEY_PRESS + edit->start_display);
     if (exp) {
 	if (!*exp) {
@@ -2716,7 +2716,7 @@ int edit_sort_cmd (WEdit * edit)
 	edit_error_dialog (_(" Sort block "), _(" You must first highlight a block of text. "));
 	return 0;
     }
-    edit_save_block (edit, catstrs (home_dir, BLOCK_FILE, 0), start_mark, end_mark);
+    edit_save_block (edit, catstrs (home_dir, BLOCK_FILE, NULL), start_mark, end_mark);
 
     exp = old ? old : "";
 
@@ -2730,7 +2730,7 @@ int edit_sort_cmd (WEdit * edit)
 	free (old);
     old = exp;
 
-    e = system (catstrs (" sort ", exp, " ", home_dir, BLOCK_FILE, " > ", home_dir, TEMP_FILE, 0));
+    e = system (catstrs (" sort ", exp, " ", home_dir, BLOCK_FILE, " > ", home_dir, TEMP_FILE, NULL));
     if (e) {
 	if (e == -1 || e == 127) {
 	    edit_error_dialog (_(" Sort "), 
@@ -2741,7 +2741,7 @@ int edit_sort_cmd (WEdit * edit)
 	    sprintf (q, "%d ", e);
 	    edit_error_dialog (_(" Sort "), 
 /* Not essential to translate */
-	    catstrs (_(" Sort returned non-zero: "), q, 0));
+	    catstrs (_(" Sort returned non-zero: "), q, NULL));
 	}
 	return -1;
     }
@@ -2750,7 +2750,7 @@ int edit_sort_cmd (WEdit * edit)
 
     if (edit_block_delete_cmd (edit))
 	return 1;
-    edit_insert_file (edit, catstrs (home_dir, TEMP_FILE, 0));
+    edit_insert_file (edit, catstrs (home_dir, TEMP_FILE, NULL));
     return 0;
 }
 
@@ -2770,8 +2770,8 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
 		_(" You must first highlight a block of text. "));
 	    return;
 	}
-	edit_save_block (edit, b = catstrs (home_dir, BLOCK_FILE, 0), start_mark, end_mark);
-	my_system (0, shell, catstrs (home_dir, shell_cmd, 0));
+	edit_save_block (edit, b = catstrs (home_dir, BLOCK_FILE, NULL), start_mark, end_mark);
+	my_system (0, shell, catstrs (home_dir, shell_cmd, NULL));
 	edit_refresh_cmd (edit);
     } else {
 	my_system (0, shell, shell_cmd);
@@ -2780,7 +2780,7 @@ void edit_block_process_cmd (WEdit * edit, const char *shell_cmd, int block)
 
     edit->force |= REDRAW_COMPLETELY;
 
-    f = catstrs (home_dir, ERROR_FILE, 0);
+    f = catstrs (home_dir, ERROR_FILE, NULL);
 
     if (block) {
 	if (stat (f, &s) == 0) {
