@@ -395,7 +395,7 @@ void CDrawEditMenuButtons (const char *ident, Window parent, Window focus_return
 {
     int d;
 
-    CDrawMenuButton (catstrs (ident, ".filemenu", 0), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 8,
+    CDrawMenuButton (catstrs (ident, ".filemenu", NULL), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 8,
 /* The following are menu options. Do not change the key bindings (eg. C-o) and preserve '\t' */
 		     _(" File "),
 		     _("Open...\tC-o"), (int) '~', menu_cmd, (unsigned long) CK_Load,
@@ -408,11 +408,11 @@ void CDrawEditMenuButtons (const char *ident, Window parent, Window focus_return
 		     _("Copy to file...\tC-f"), (int) '~', menu_cmd, (unsigned long) CK_Save_Block
 	);
 /* Tool hint */
-    CSetToolHint (catstrs (ident, ".filemenu", 0), _("Disk operations and file indexing/searching"));
+    CSetToolHint (catstrs (ident, ".filemenu", NULL), _("Disk operations and file indexing/searching"));
 
     CGetHintPos (&x, &d);
 
-    CDrawMenuButton (catstrs (ident, ".editmenu", 0), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 20,
+    CDrawMenuButton (catstrs (ident, ".editmenu", NULL), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 20,
 		     _(" Edit "),
 		     _("Toggle mark\tF3"), (int) '~', menu_cmd, (unsigned long) CK_Mark,
 		     _("Toggle mark columns\tC-b"), (int) '~', menu_cmd, (unsigned long) CK_Column_Mark,
@@ -436,11 +436,11 @@ void CDrawEditMenuButtons (const char *ident, Window parent, Window focus_return
 		     _("Undo\tC-BackSpace"), (int) '~', menu_cmd, (unsigned long) CK_Undo
 	);
 /* Tool hint */
-    CSetToolHint (catstrs (ident, ".editmenu", 0), _("Manipulating blocks of text"));
+    CSetToolHint (catstrs (ident, ".editmenu", NULL), _("Manipulating blocks of text"));
 
     CGetHintPos (&x, &d);
 
-    CDrawMenuButton (catstrs (ident, ".searchmenu", 0), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 4,
+    CDrawMenuButton (catstrs (ident, ".searchmenu", NULL), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 4,
 		     _(" Srch/Replce "),
 		     _("Search...\tF7"), (int) '~', menu_cmd, (unsigned long) CK_Find,
 		     _("Search again\tF17"), (int) '~', menu_cmd, (unsigned long) CK_Find_Again,
@@ -448,11 +448,11 @@ void CDrawEditMenuButtons (const char *ident, Window parent, Window focus_return
 		     _("Replace again\tF14"), (int) '~', menu_cmd, (unsigned long) CK_Replace_Again
 	);
 /* Tool hint */
-    CSetToolHint (catstrs (ident, ".searchmenu", 0), _("Search for and replace text"));
+    CSetToolHint (catstrs (ident, ".searchmenu", NULL), _("Search for and replace text"));
 
     CGetHintPos (&x, &d);
 
-    CDrawMenuButton (catstrs (ident, ".commandmenu", 0), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 12,
+    CDrawMenuButton (catstrs (ident, ".commandmenu", NULL), parent, focus_return, x, y, AUTO_WIDTH, AUTO_HEIGHT, 12,
 		     _(" Command "),
 		     _("Goto line...\tM-l"), (int) '~', menu_cmd, (unsigned long) CK_Goto,
 		     _("Goto matching bracket\tM-b"), (int) '~', menu_cmd, (unsigned long) CK_Match_Bracket,
@@ -468,7 +468,7 @@ void CDrawEditMenuButtons (const char *ident, Window parent, Window focus_return
 		     _("Refresh display\tC-l"), (int) '~', menu_cmd, (unsigned long) CK_Refresh
 	);
 /* Tool hint */
-    CSetToolHint (catstrs (ident, ".commandmenu", 0), _("Macros and internal commands"));
+    CSetToolHint (catstrs (ident, ".commandmenu", NULL), _("Macros and internal commands"));
 }
 
 
