@@ -462,7 +462,7 @@ CWidget *CDrawEditor (const char *identifier, Window parent, int x, int y,
 	w->label = (char *) strdup ("");
 
     if (!made_directory) {
-	mkdir (catstrs (home_dir, EDIT_DIR, 0), 0700);
+	mkdir (catstrs (home_dir, EDIT_DIR, NULL), 0700);
 	made_directory = 1;
     }
     e = w->editor = CMalloc (sizeof (WEdit));
@@ -489,7 +489,7 @@ CWidget *CDrawEditor (const char *identifier, Window parent, int x, int y,
     e->widget = w;
 
     if (!(options & EDITOR_NO_SCROLL)) {
-	w->vert_scrollbar = CDrawVerticalScrollbar (catstrs (identifier, ".vsc", 0), parent,
+	w->vert_scrollbar = CDrawVerticalScrollbar (catstrs (identifier, ".vsc", NULL), parent,
 						    x + width + EDIT_FRAME_W + WIDGET_SPACING, y, height + EDIT_FRAME_H,
 						    AUTO_WIDTH, 0, 0);
 	CSetScrollbarCallback (w->vert_scrollbar->ident, w->ident, link_scrollbar_to_editor);
@@ -499,7 +499,7 @@ CWidget *CDrawEditor (const char *identifier, Window parent, int x, int y,
     set_hint_pos (x + width + EDIT_FRAME_W + WIDGET_SPACING,
 		  y + height + EDIT_FRAME_H + WIDGET_SPACING + extra_space_for_hscroll);
     if (extra_space_for_hscroll) {
-	w->hori_scrollbar = CDrawHorizontalScrollbar (catstrs (identifier, ".hsc", 0), parent,
+	w->hori_scrollbar = CDrawHorizontalScrollbar (catstrs (identifier, ".hsc", NULL), parent,
 						      x, y + height + EDIT_FRAME_H, width + EDIT_FRAME_W,
 						      AUTO_HEIGHT, 0, 0);
 	CSetScrollbarCallback (w->hori_scrollbar->ident, w->ident, link_hscrollbar_to_editor);
@@ -507,7 +507,7 @@ CWidget *CDrawEditor (const char *identifier, Window parent, int x, int y,
     CGetHintPos (0, &y);
     if (!(options & EDITOR_NO_TEXT)) {
 	CPushFont ("widget", 0);
-	CDrawStatus (catstrs (identifier, ".text", 0), parent, x, y, width + EDIT_FRAME_W, e->filename);
+	CDrawStatus (catstrs (identifier, ".text", NULL), parent, x, y, width + EDIT_FRAME_W, e->filename);
 	CPopFont ();
     }
     CGetHintPos (0, &y);
@@ -1208,7 +1208,7 @@ int edit (const char *_file, int line)
 	memcpy (option_backup_ext, (char *) &option_backup_ext_int, sizeof (int));
     }
     if (!made_directory) {
-	mkdir (catstrs (home_dir, EDIT_DIR, 0), 0700);
+	mkdir (catstrs (home_dir, EDIT_DIR, NULL), 0700);
 	made_directory = 1;
     }
     if (_file) {
