@@ -536,7 +536,7 @@ CWidget *CDrawFieldedTextbox (const char *identifier, Window parent, int x, int
     wdt->funcs = mouse_funcs_new (wdt, &fielded_mouse_funcs);
 
     if (h > 80 && height != AUTO_HEIGHT) {
-	wdt->vert_scrollbar = CDrawVerticalScrollbar (scroll = catstrs (identifier, ".vsc", 0), parent,
+	wdt->vert_scrollbar = CDrawVerticalScrollbar (scroll = catstrs (identifier, ".vsc", NULL), parent,
 			 x + w + WIDGET_SPACING, y, h, AUTO_WIDTH, 0, 0);
 	CSetScrollbarCallback (wdt->vert_scrollbar->ident, wdt->ident, link_scrollbar_to_fielded_textbox);
 	CGetHintPos (&x_hint, 0);
@@ -545,7 +545,7 @@ CWidget *CDrawFieldedTextbox (const char *identifier, Window parent, int x, int
     }
 
     if (w > 80 && width != AUTO_WIDTH) {
-	wdt->hori_scrollbar = CDrawHorizontalScrollbar (scroll = catstrs (identifier, ".hsc", 0), parent,
+	wdt->hori_scrollbar = CDrawHorizontalScrollbar (scroll = catstrs (identifier, ".hsc", NULL), parent,
 			 x, y + h + WIDGET_SPACING, w, (*look->get_fielded_textbox_hscrollbar_width) (), 0, 65535);
 	CSetScrollbarCallback (wdt->hori_scrollbar->ident, wdt->ident, link_h_scrollbar_to_fielded_textbox);
 	CGetHintPos (0, &y_hint);
