@@ -770,7 +770,7 @@ static void gtk_edit_init (GtkEdit * edit)
     gtk_edit_configure_font_dimensions (edit);
 
     if (!made_directory) {
-	mkdir (catstrs (home_dir, EDIT_DIR, 0), 0700);
+	mkdir (catstrs (home_dir, EDIT_DIR, NULL), 0700);
 	made_directory = 1;
     }
     GTK_EDITABLE (edit)->editable = TRUE;
