@@ -187,10 +187,10 @@ static void get_resources (void)
     XrmValue value;
     XrmDatabase rdb;
     XrmInitialize ();
-    rdb = XrmGetFileDatabase (catstrs (getenv ("HOME"), "/.Xdefaults", 0));
+    rdb = XrmGetFileDatabase (catstrs (getenv ("HOME"), "/.Xdefaults", NULL));
     if (rdb != NULL) {
 	for (i = 0; resources[i].name; i++) {
-	    char *rname = catstrs (CAppName, "*", resources[i].name, 0);
+	    char *rname = catstrs (CAppName, "*", resources[i].name, NULL);
 	    if (XrmGetResource (rdb, rname, rname,
 				&type, &value)) {
 		*resources[i].value = value.addr;
