@@ -291,7 +291,7 @@ void put_all_lists (char *list)
 	}
     }
 }
-    
+
 static char *draw_text_input_history (CWidget * text_input)
 {
     char *p, *r;
@@ -330,6 +330,69 @@ static char *draw_text_input_history (CWidget * text_input)
     return r;
 }
 
+static char *draw_selection_history (CWidget * text_input)
+{
+    CWidget *w;
+    char *p, *r;
+    int x, y;
+    long len;
+    int columns, lines;
+    x = text_input->x;
+    CPushFont ("editor", 0);
+    columns = (text_input->width - WIDGET_SPACING * 3 - 4 - 6 - 20) / FONT_MEAN_WIDTH;
+    w = CWidgetOfWindow (text_input->parentid);
+    if (!w) {
+	CPopFont ();
+	return 0;
+    }
+    if (text_input->y > w->height / 2) {
+	lines = (text_input->y - 2 - WIDGET_SPACING * 2 - 4 - 6) / FONT_PIX_PER_LINE;
+	y = text_input->y - lines * FONT_PIX_PER_LINE - WIDGET_SPACING * 2 - 4 - 6;
+    } else {
+	lines =
+	    (w->height - text_input->height - text_input->y - 2 - WIDGET_SPACING * 2 - 4 -
+	     6) / FONT_PIX_PER_LINE;
+	y = text_input->y + text_input->height;
+    }
+    p = edit_get_text_from_selection_history (w->winid, x, y, columns, lines, &len);
+    if (p) {
+	r = (char *) CMalloc (len + 1);
+	strncpy (r, p, len + 1);
+    } else {
+	r = NULL;
+    }
+    CPopFont ();
+    return r;
+}
+
+static char *draw_selection_completion (CWidget * text_input)
+{
+    CWidget *w;
+    char *r;
+    int x, y;
+    int columns, lines;
+    x = text_input->x;
+    CPushFont ("editor", 0);
+    columns = (text_input->width - WIDGET_SPACING * 3 - 4 - 6 - 20) / FONT_MEAN_WIDTH;
+    w = CWidgetOfWindow (text_input->parentid);
+    if (!w) {
+	CPopFont ();
+	return 0;
+    }
+    if (text_input->y > w->height / 2) {
+	lines = (text_input->y - 2 - WIDGET_SPACING * 2 - 4 - 6) / FONT_PIX_PER_LINE;
+	y = text_input->y - lines * FONT_PIX_PER_LINE - WIDGET_SPACING * 2 - 4 - 6;
+    } else {
+	lines =
+	    (w->height - text_input->height - text_input->y - 2 - WIDGET_SPACING * 2 - 4 -
+	     6) / FONT_PIX_PER_LINE;
+	y = text_input->y + text_input->height;
+    }
+    r = user_file_list_complete (w->winid, x, y, columns, lines, text_input->text);
+    CPopFont ();
+    return r;
+}
+
 #if 0
 wchar_t *mbstowcs_dup (unsigned char *s);
 int wchar_t_strlen (wchar_t * s);
@@ -803,6 +866,23 @@ int eh_textinput (CWidget * w, XEvent * xevent, CEvent * cwevent)
 	    unsigned char *intext;
 	    intext = (unsigned char *) w->text;
 	    switch (cwevent->command) {
+	    case CK_Complete:
+		u = draw_selection_completion (w);
+		if (u) {
+		    w->cursor = 0;
+		    w->text[0] = '\0';
+		    while (*u)
+			input_insert (w, *u++);
+		}
+		handled = 1;
+		break;
+	    case CK_Selection_History:
+		u = draw_selection_history (w);
+		if (u)
+		    while (*u)
+			input_insert (w, *u++);
+		handled = 1;
+		break;
 	    case CK_Insert_Unicode:
 		u = (char *) CGetUnichar (CRoot, "Unicode characters");
 		if (u)
