@@ -64,7 +64,7 @@ char *loadfile (const char *filename, long *filelen)
 	free (data);
 	return NULL;
     }
-    if (read (file, data, *filelen) < *filelen) {
+    if (readall (file, data, *filelen) < *filelen) {
 	close (file);
 	free (data);
 	return NULL;
