@@ -460,7 +460,7 @@ static Window draw_file_browser (const char *identifier, Window parent, int x, i
     (CIdent (identifier))->options |= WINDOW_ALWAYS_RAISED;
     CHourGlass (CFirstWindow);
     for (;;) {
-	filelist = get_file_entry_list (dir, FILELIST_FILES_ONLY, CLastInput (catstrs (identifier, ".filt", 0)));
+	filelist = get_file_entry_list (dir, FILELIST_FILES_ONLY, CLastInput (catstrs (identifier, ".filt", NULL)));
 	if (!filelist) {
 	    char *s;
 	    s = strrchr (dir, '/');
@@ -484,34 +484,34 @@ static Window draw_file_browser (const char *identifier, Window parent, int x, i
 	*++p = '/';
 	*++p = '\0';
     }
-    (CDrawText (catstrs (identifier, ".dir", 0), win, x, y, "%s", resolved_path))->position |= POSITION_FILL;
+    (CDrawText (catstrs (identifier, ".dir", NULL), win, x, y, "%s", resolved_path))->position |= POSITION_FILL;
     free (resolved_path);
     CGetHintPos (0, &y);
     reset_hint_pos (x, y);
     y3 = y;
-    (w = CDrawFilelist (catstrs (identifier, ".fbox", 0), win, x, y,
+    (w = CDrawFilelist (catstrs (identifier, ".fbox", NULL), win, x, y,
 		  FONT_MEAN_WIDTH * option_file_browser_width + 7, FONT_PIX_PER_LINE * option_file_browser_height + 6, 0, 0, filelist, TEXTBOX_FILE_LIST))->position |= POSITION_WIDTH | POSITION_HEIGHT;
     xdnd_set_type_list (CDndClass, w->winid, xdnd_typelist_send[DndFiles]);
-    (CIdent (catstrs (identifier, ".fbox", 0)))->options |= TEXTBOX_MARK_WHOLE_LINES;
+    (CIdent (catstrs (identifier, ".fbox", NULL)))->options |= TEXTBOX_MARK_WHOLE_LINES;
 
 /* the vertical scroll bar is named the same as the text box, with a ".vsc" at the end: */
-    CSetMovement (catstrs (identifier, ".fbox.vsc", 0), POSITION_HEIGHT | POSITION_RIGHT);
-    CSetMovement (catstrs (identifier, ".fbox.hsc", 0), POSITION_WIDTH | POSITION_BOTTOM);
+    CSetMovement (catstrs (identifier, ".fbox.vsc", NULL), POSITION_HEIGHT | POSITION_RIGHT);
+    CSetMovement (catstrs (identifier, ".fbox.hsc", NULL), POSITION_WIDTH | POSITION_BOTTOM);
     CGetHintPos (&x2, &y2);
     x3 = x2;
-    (w = CDrawFilelist (catstrs (identifier, ".dbox", 0), win, x2, y + TICK_BUTTON_WIDTH + WIDGET_SPACING,
+    (w = CDrawFilelist (catstrs (identifier, ".dbox", NULL), win, x2, y + TICK_BUTTON_WIDTH + WIDGET_SPACING,
 		  FONT_MEAN_WIDTH * 24 + 7, y2 - WIDGET_SPACING * 3 - 12 - y - TICK_BUTTON_WIDTH, 0, 0, directorylist, TEXTBOX_FILE_LIST))->position |= POSITION_HEIGHT | POSITION_RIGHT;
     xdnd_set_type_list (CDndClass, w->winid, xdnd_typelist_send[DndFiles]);
 
 /* Toolhint */
-    CSetToolHint (catstrs (identifier, ".dbox", 0), _("Double click to enter directories"));
-    (CIdent (catstrs (identifier, ".dbox", 0)))->options |= TEXTBOX_MARK_WHOLE_LINES;
-    CSetMovement (catstrs (identifier, ".dbox.vsc", 0), POSITION_HEIGHT | POSITION_RIGHT);
-    CSetMovement (catstrs (identifier, ".dbox.hsc", 0), POSITION_RIGHT | POSITION_BOTTOM);
+    CSetToolHint (catstrs (identifier, ".dbox", NULL), _("Double click to enter directories"));
+    (CIdent (catstrs (identifier, ".dbox", NULL)))->options |= TEXTBOX_MARK_WHOLE_LINES;
+    CSetMovement (catstrs (identifier, ".dbox.vsc", NULL), POSITION_HEIGHT | POSITION_RIGHT);
+    CSetMovement (catstrs (identifier, ".dbox.hsc", NULL), POSITION_RIGHT | POSITION_BOTTOM);
     CGetHintPos (&x2, &y2);
-    (CDrawText (catstrs (identifier, ".msg", 0), win, x, y2, _("Ctrl-Tab to complete, Alt-Ins for clip history, Shift-Up for history")))->position |= POSITION_FILL | POSITION_BOTTOM;
+    (CDrawText (catstrs (identifier, ".msg", NULL), win, x, y2, _("Ctrl-Tab to complete, Alt-Ins for clip history, Shift-Up for history")))->position |= POSITION_FILL | POSITION_BOTTOM;
     CGetHintPos (0, &y2);
-    (w = CDrawTextInput (catstrs (identifier, ".finp", 0), win, x, y2,
+    (w = CDrawTextInput (catstrs (identifier, ".finp", NULL), win, x, y2,
 		    WIDGET_SPACING * 2 - 2, AUTO_HEIGHT, 256, file))->position |= POSITION_FILL | POSITION_BOTTOM;
     xdnd_set_type_list (CDndClass, w->winid, xdnd_typelist_send[DndFile]);
     w->funcs->types = DndFile;
@@ -519,22 +519,22 @@ static Window draw_file_browser (const char *identifier, Window parent, int x, i
 
     CGetHintPos (0, &y2);
 /* Label for file filter input line. For example, to list files matching '*.c' */
-    (CDrawText (catstrs (identifier, ".filx", 0), win, x, y2, _("Filter : ")))->position |= POSITION_BOTTOM;
+    (CDrawText (catstrs (identifier, ".filx", NULL), win, x, y2, _("Filter : ")))->position |= POSITION_BOTTOM;
     CGetHintPos (&x, 0);
-    (CDrawTextInput (catstrs (identifier, ".filt", 0), win, x, y2,
+    (CDrawTextInput (catstrs (identifier, ".filt", NULL), win, x, y2,
 		    WIDGET_SPACING * 2 - 2, AUTO_HEIGHT, 256, TEXTINPUT_LAST_INPUT))->position |= POSITION_FILL | POSITION_BOTTOM;
 /* Toolhint */
-    CSetToolHint (catstrs (identifier, ".filt", 0), _("List only files matching this shell filter"));
-    CSetToolHint (catstrs (identifier, ".filx", 0), _("List only files matching this shell filter"));
-    (CDrawPixmapButton (catstrs (identifier, ".ok", 0), win, x3, y3,
+    CSetToolHint (catstrs (identifier, ".filt", NULL), _("List only files matching this shell filter"));
+    CSetToolHint (catstrs (identifier, ".filx", NULL), _("List only files matching this shell filter"));
+    (CDrawPixmapButton (catstrs (identifier, ".ok", NULL), win, x3, y3,
 		       PIXMAP_BUTTON_TICK))->position |= POSITION_RIGHT;
 /* Toolhint */
-    CSetToolHint (catstrs (identifier, ".ok", 0), _("Accept, Enter"));
+    CSetToolHint (catstrs (identifier, ".ok", NULL), _("Accept, Enter"));
 
-    (CDrawPixmapButton (catstrs (identifier, ".cancel", 0), win, x2 - WIDGET_SPACING * 2 - TICK_BUTTON_WIDTH - 20, y3,
+    (CDrawPixmapButton (catstrs (identifier, ".cancel", NULL), win, x2 - WIDGET_SPACING * 2 - TICK_BUTTON_WIDTH - 20, y3,
 		       PIXMAP_BUTTON_CROSS))->position |= POSITION_RIGHT;
 /* Toolhint */
-    CSetToolHint (catstrs (identifier, ".cancel", 0), _("Abort this dialog, Escape"));
+    CSetToolHint (catstrs (identifier, ".cancel", NULL), _("Abort this dialog, Escape"));
     CSetSizeHintPos (identifier);
     CMapDialog (identifier);
     y = (CIdent (identifier))->height;
@@ -609,7 +609,7 @@ static char *file_error (void)
 /* The returned value, 'errno' has an unknown meaning */
 	    error_msg = _ ("strange errno");
 #endif
-	return catstrs ("[", error_msg, "]", 0);
+	return catstrs ("[", error_msg, "]", NULL);
     }
     return "";
 }
@@ -624,19 +624,19 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 {
     struct stat st;
     char *q;
-    char *idd = catstrs (identifier, ".dbox", 0);
-    char *idf = catstrs (identifier, ".fbox", 0);
+    char *idd = catstrs (identifier, ".dbox", NULL);
+    char *idf = catstrs (identifier, ".fbox", NULL);
     static char estr[MAX_PATH_LEN + 1];
-    CWidget *directory = CIdent (catstrs (identifier, ".dir", 0));
+    CWidget *directory = CIdent (catstrs (identifier, ".dir", NULL));
     CWidget *filelist = CIdent (idf);
     CWidget *directorylist = CIdent (idd);
-    CWidget *textinput = CIdent (catstrs (identifier, ".finp", 0));
-    CWidget *filterinput = CIdent (catstrs (identifier, ".filt", 0));
+    CWidget *textinput = CIdent (catstrs (identifier, ".finp", NULL));
+    CWidget *filterinput = CIdent (catstrs (identifier, ".filt", NULL));
 
     CSetDndDirectory (directory->text);
 
     if (cwevent->type == ButtonPress || cwevent->type == KeyPress)
-	CRedrawText (catstrs (identifier, ".msg", 0), "%s", file_error());
+	CRedrawText (catstrs (identifier, ".msg", NULL), "%s", file_error());
 
     if (!strcmp (cwevent->ident, filterinput->ident) && cwevent->command == CK_Enter) {
 	struct file_entry *f;
@@ -646,7 +646,7 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 	    CExpose (filterinput->ident);
 	}
 	CHourGlass (CFirstWindow);
-	CRedrawFilelist (catstrs (identifier, ".fbox", 0),
+	CRedrawFilelist (catstrs (identifier, ".fbox", NULL),
 			 f = get_file_entry_list (directory->text, FILELIST_FILES_ONLY, filterinput->text),
 			 0);
 	if (f)
@@ -674,7 +674,7 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
     if (!strcmp (cwevent->ident, idd)) {
 	if (cwevent->button == Button1 || cwevent->command == CK_Enter) {
 	    q = (CGetFilelistLine (directorylist, directorylist->cursor))->name;
-	    CDrawTextInput (catstrs (identifier, ".finp", 0), CIdent (identifier)->winid, textinput->x, textinput->y,
+	    CDrawTextInput (catstrs (identifier, ".finp", NULL), CIdent (identifier)->winid, textinput->x, textinput->y,
 			textinput->width, textinput->height, 256, q);
 	} else if (cwevent->insert > 0) {
 	    input_insert (textinput, cwevent->insert);
@@ -739,11 +739,11 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 	    break;
 	}
     }
-    if (cwevent->command == CK_Cancel || !strcmp (cwevent->ident, catstrs (identifier, ".cancel", 0)))
+    if (cwevent->command == CK_Cancel || !strcmp (cwevent->ident, catstrs (identifier, ".cancel", NULL)))
 	return 0;
 
     if (options & GETFILE_GET_DIRECTORY) {
-	if (!strcmp (cwevent->ident, catstrs (identifier, ".ok", 0))) {
+	if (!strcmp (cwevent->ident, catstrs (identifier, ".ok", NULL))) {
 	    char *resolved_path;
 	    resolved_path = pathdup (directory->text);
 	    strcpy (estr, resolved_path);
@@ -751,11 +751,11 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 	    return estr;
 	}
     }
-    if (!strcmp (cwevent->ident, catstrs (identifier, ".ok", 0))
+    if (!strcmp (cwevent->ident, catstrs (identifier, ".ok", NULL))
 	|| cwevent->command == CK_Enter
-	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".finp", 0)))
-	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".dbox", 0)))
-	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".fbox", 0)))) {
+	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".finp", NULL)))
+	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".dbox", NULL)))
+	|| (cwevent->double_click && !strcmp (cwevent->ident, catstrs (identifier, ".fbox", NULL)))) {
 	char *resolved_path;
 	if (*textinput->text == '/' || *textinput->text == '~')
 	    *estr = '\0';
@@ -779,7 +779,7 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 		    return estr;
 	    }
 /* ********* */
-	    CRedrawText (catstrs (identifier, ".msg", 0), "%s", file_error());
+	    CRedrawText (catstrs (identifier, ".msg", NULL), "%s", file_error());
 	    return "";
 	}
 	if (S_ISDIR (st.st_mode)) {
@@ -788,13 +788,13 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 	    g = get_file_entry_list (estr, FILELIST_FILES_ONLY, filterinput->text);
 	    CUnHourGlass (CFirstWindow);
 	    if (g) {
-		CRedrawFilelist (catstrs (identifier, ".fbox", 0), g, 0);
-		CRedrawFilelist (catstrs (identifier, ".dbox", 0), f = get_file_entry_list (estr, FILELIST_DIRECTORIES_ONLY, ""), 0);
+		CRedrawFilelist (catstrs (identifier, ".fbox", NULL), g, 0);
+		CRedrawFilelist (catstrs (identifier, ".dbox", NULL), f = get_file_entry_list (estr, FILELIST_DIRECTORIES_ONLY, ""), 0);
 		if (*q != '/') {
 		    *++q = '/';
 		    *++q = '\0';
 		}
-		CRedrawText (catstrs (identifier, ".dir", 0), "%s", estr);
+		CRedrawText (catstrs (identifier, ".dir", NULL), "%s", estr);
 		if (options & GETFILE_BROWSER)
 		    CAddToTextInputHistory (textinput->ident, estr);
 	    }
@@ -805,7 +805,7 @@ static char *handle_browser (const char *identifier, CEvent * cwevent, int optio
 	    return "";
 	} else {
 	    if (options & (GETFILE_GET_DIRECTORY | GETFILE_BROWSER)) {
-		CRedrawText (catstrs (identifier, ".msg", 0), "%s", file_error());
+		CRedrawText (catstrs (identifier, ".msg", NULL), "%s", file_error());
 		return "";
 	    }
 	    return estr;	/* entry exists and is a file */
@@ -896,7 +896,7 @@ static int cb_browser (CWidget * w, XEvent * x, CEvent * c)
     if (s)
 	*s = 0;
     if (!handle_browser (id, c, GETFILE_BROWSER)) {
-	w = CIdent (catstrs (id, ".finp", 0));
+	w = CIdent (catstrs (id, ".finp", NULL));
 	if (w)
 	    if (w->text) {
 		free (w->text);
@@ -918,14 +918,14 @@ void look_cool_draw_browser (const char *ident, Window parent, int x, int y,
 
     draw_file_browser (ident, parent, x, y, dir, file, label);
 
-    CAddCallback (catstrs (ident, ".dbox", 0), cb_browser);
-    CAddCallback (catstrs (ident, ".fbox", 0), cb_browser);
-    CAddCallback (catstrs (ident, ".finp", 0), cb_browser);
-    CAddCallback (catstrs (ident, ".filt", 0), cb_browser);
-    CAddCallback (catstrs (ident, ".ok", 0), cb_browser);
-    CAddCallback (catstrs (ident, ".cancel", 0), cb_browser);
+    CAddCallback (catstrs (ident, ".dbox", NULL), cb_browser);
+    CAddCallback (catstrs (ident, ".fbox", NULL), cb_browser);
+    CAddCallback (catstrs (ident, ".finp", NULL), cb_browser);
+    CAddCallback (catstrs (ident, ".filt", NULL), cb_browser);
+    CAddCallback (catstrs (ident, ".ok", NULL), cb_browser);
+    CAddCallback (catstrs (ident, ".cancel", NULL), cb_browser);
 
-    CFocus (CIdent (catstrs (ident, ".finp", 0)));
+    CFocus (CIdent (catstrs (ident, ".finp", NULL)));
 }
 
 
