@@ -624,7 +624,7 @@ static void look_gtk_render_switch (CWidget * wdt)
     bevel_background_color = COLOR_FLAT;
 }
 
-extern unsigned long edit_normal_background_color;
+extern int edit_normal_background_color;
 
 static void look_gtk_edit_render_tidbits (CWidget * wdt)
 {
@@ -653,7 +653,7 @@ extern CWidget *look_cool_draw_tick_cancel_button (char *ident, Window win, int
 
 extern CWidget *look_cool_draw_cross_cancel_button (char *ident, Window win, int x, int y);
 
-extern unsigned long option_text_bg_normal;
+extern int option_text_bg_normal;
 
 static void look_gtk_render_fielded_textbox_tidbits (CWidget * w, int isfocussed)
 {
