@@ -247,7 +247,7 @@ static CWidget *pull_down (CWidget * button) /* must create a new widget */
 
     x += button->firstcolumn;
 
-    menu = CSetupWidget (catstrs (button->ident, ".pull", 0), CRoot, x,
+    menu = CSetupWidget (catstrs (button->ident, ".pull", NULL), CRoot, x,
 	   y + button->height, width, height, C_MENU_WIDGET, INPUT_KEY, COLOR_FLAT, 0);
     menu->options |= (button->options & MENU_AUTO_PULL_UP);
 
@@ -487,7 +487,7 @@ CWidget *CDrawMenuButton (const char *ident, Window parent, Window focus_return,
 	char *text;
 	text = va_arg (ap, char *);
 	text = text ? text : "";
-	m[i].text = (char *) strdup (catstrs (" ", text, " ", 0));
+	m[i].text = (char *) strdup (catstrs (" ", text, " ", NULL));
 	m[i].hot_key = va_arg (ap, int);
 	m[i].call_back = va_arg (ap, callfn);
 	m[i].data = va_arg (ap, unsigned long);
@@ -511,7 +511,7 @@ void insert_menu_item (CWidget * w, int i, const char *text, int hot_key, callfn
     memcpy (m + i + 1, w->menu + i, (w->numlines - i) * sizeof (struct menu_item));
     free (w->menu);
     w->menu = m;
-    m[i].text = (char *) strdup (catstrs (" ", text, " ", 0));
+    m[i].text = (char *) strdup (catstrs (" ", text, " ", NULL));
     m[i].hot_key = hot_key;
     m[i].call_back = call_back;
     m[i].data = data;
@@ -644,7 +644,7 @@ void CReplaceMenuItem (const char *ident, const char *old_text, const char *new_
     }
     m = w->menu;
     free (m[i].text);
-    m[i].text = (char *) strdup (catstrs (" ", new_text, " ", 0));
+    m[i].text = (char *) strdup (catstrs (" ", new_text, " ", NULL));
     m[i].hot_key = hot_key;
     m[i].call_back = call_back;
     m[i].data = data;
