@@ -53,6 +53,46 @@ void set_signal_handlers_to_default (void)
     signal (SIGALRM, SIG_IGN);
 }
 
+/* returns non-zero if the file exists in the PATH. mimicks the behavior
+of execvp */
+int PATH_search (const char *file)
+{
+    int fd;
+    if (strchr (file, '/')) {
+	if ((fd = open (file, O_RDONLY)) >= 0) {
+	    close (fd);
+	    return 1;
+	}
+    } else {
+	char *path, *p, *name;
+	int len;
+	if (!(path = getenv ("PATH")))
+	    return 0;
+	len = strlen ((char *) file) + 1;
+	name = (char *) malloc (strlen (path) + len + 1);
+	p = path;
+	do {
+	    path = p;
+	    if (!(p = strchr (path, ':')))
+		p = path + strlen (path);
+	    if (p == path) {	/* double colons */
+		strcpy (name, (char *) file);
+	    } else {
+		memcpy (name, path, (int) (p - path));
+		strcpy (&name[(int) (p - path)], "/");
+		strcat (name, (char *) file);
+	    }
+	    if ((fd = open (name, O_RDONLY)) >= 0) {
+		free (name);
+		close (fd);
+		return 1;
+	    }
+	} while (*p++);
+	free (name);
+    }
+    return 0;
+}
+
 
 /*
    This opens a process as a pipe. 'in', 'out' and 'err' are pointers to file handles
@@ -73,6 +113,14 @@ pid_t triple_pipe_open (int *in, int *out, int *err, int mix, const char *file,
     int e;
     int f0[2], f1[2], f2[2];
 
+/* we must at least check if the file is in the PATH and is readable.
+catching this basic condition helps a lot even though an exec may still
+fail for other reasons: */
+    if (!PATH_search (file)) {
+	errno = ENOENT;
+	return -1;
+    }
+
     e = (pipe (f0) | pipe (f1) | pipe (f2));
 
     if (e) {
