@@ -1635,7 +1635,7 @@ void edit_load_syntax (WEdit * edit, char **names, char *type)
 	if (!*edit->filename && !type)
 	    return;
     }
-    f = catstrs (home_dir, SYNTAX_FILE, 0);
+    f = catstrs (home_dir, SYNTAX_FILE, NULL);
     r = edit_read_syntax_file (edit, names, f, edit ? edit->filename : 0, get_first_editor_line (edit), type);
     if (r == -1) {
 	edit_free_syntax_rules (edit);
