@@ -250,7 +250,7 @@ CWidget *CDrawTextbox (const char *identifier, Window parent, int x, int y,
 
     if (height > 80) {
 /* this will also set the hint position, set_hint_pos() */
-	wdt->vert_scrollbar = CDrawVerticalScrollbar (scroll = catstrs (identifier, ".vsc", 0), parent,
+	wdt->vert_scrollbar = CDrawVerticalScrollbar (scroll = catstrs (identifier, ".vsc", NULL), parent,
 		x + width + WIDGET_SPACING, y, height, AUTO_WIDTH, 0, 0);
 	CSetScrollbarCallback (wdt->vert_scrollbar->ident, wdt->ident, link_scrollbar_to_textbox);
     } else {
