@@ -17,6 +17,9 @@
    02111-1307, USA.
  */
 
+#undef abs
+#define abs(x) ((x) < 0 ? -(x) : (x))
+
 
 #ifdef WRAP
 #ifdef INTERP
