@@ -315,7 +315,7 @@ static void new_behaviour_message (WEdit * edit)
 {
     char *filename;
     int fd;
-    filename = catstrs (home_dir, PARMESS_FILE, 0);
+    filename = catstrs (home_dir, PARMESS_FILE, NULL);
     if ((fd = open (filename, O_RDONLY)) < 0) {
 	edit_message_dialog (_(" Format Paragraph "), "\
 This message will not be displayed again\n\
