@@ -105,6 +105,7 @@ static void IMInstantiateCallback (Display * display, XPointer client_data, XPoi
 
 void init_xlocale (void)
 {
+#ifdef LC_CTYPE
     char *xim_locale = NULL;
     xim_locale = setlocale (LC_CTYPE, 0);
     CPushFont ("editor", 0);
@@ -117,6 +118,9 @@ void init_xlocale (void)
 	    XRegisterIMInstantiateCallback (CDisplay, NULL, NULL, NULL, IMInstantiateCallback, NULL);
     }
     CPopFont ();
+#else
+    option_use_xim = 0;
+#endif
 }
 
 void setPosition (CWidget * child, CWidget * w, XPoint * pos)
